--- app_voicemail.c	2006-01-23 15:53:49.000000000 -0700
+++ app_voicemail.c.new	2006-01-23 15:52:06.000000000 -0700
@@ -111,6 +111,7 @@
 #define VM_DELETE		(1 << 12)
 #define VM_ALLOCED		(1 << 13)
 #define VM_SEARCH		(1 << 14)
+#define VM_TEMPGREETSET		(1 << 15)	/*!< Remind user temp greeting is set */
 
 #define ERROR_LOCK_PATH		-100
 
@@ -453,6 +454,8 @@
 		ast_set2_flag(vmu, ast_true(value), VM_SVMAIL);	
 	} else if (!strcasecmp(var, "review")){
 		ast_set2_flag(vmu, ast_true(value), VM_REVIEW);	
+	} else if (!strcasecmp(var, "tempgreetset")){
+		ast_set2_flag(vmu, ast_true(value), VM_TEMPGREETSET);	
 	} else if (!strcasecmp(var, "operator")){
 		ast_set2_flag(vmu, ast_true(value), VM_OPERATOR);	
 	} else if (!strcasecmp(var, "envelope")){
@@ -4007,8 +4010,48 @@
 }
 	
 /* Default English syntax */
-static int vm_intro_en(struct ast_channel *chan,struct vm_state *vms)
+static int vm_intro_en(struct ast_channel *chan, struct ast_vm_user *vmu, struct vm_state *vms)
 {
+
+/*Prompt that temp greeting is set give option to remove*/
+	int cmd =0;
+	int retries = 0;
+	char prefile[256]="";
+	snprintf(prefile,sizeof(prefile), "%s%s/%s/temp", VM_SPOOL_DIR, vmu->context, vms->username);
+	if (ast_test_flag(vmu, VM_TEMPGREETSET)) {
+		if (ast_fileexists(prefile, NULL, NULL) > 0) {
+			while((cmd >= 0) && (cmd != 't')) {
+				if (cmd)
+					retries = 0;
+				if (ast_fileexists(prefile, NULL, NULL) > 0) {
+					switch (cmd) {
+					case '1':
+						cmd = 't';
+						break;
+					case '2':
+						ast_filedelete(prefile, NULL);
+						ast_play_and_wait(chan,"vm-tempremoved");
+						cmd = 't';	
+						break;
+					case '*': 
+						cmd = 't';
+						break;
+					default:
+						if (ast_fileexists(prefile, NULL, NULL) > 0) {
+							cmd = ast_play_and_wait(chan,"vm-tempset");
+						} if (!cmd) {
+							cmd = ast_waitfordigit(chan,6000);
+						} if (!cmd) {
+							retries++;
+						} if (retries > 3) {
+							cmd = 't';
+						}
+					}
+				}
+			}
+		}
+	}
+
 	/* Introduce messages they have */
 	int res;
 	res = ast_play_and_wait(chan, "vm-youhave");
@@ -4492,7 +4535,7 @@
 	return res;
 }
 
-static int vm_intro(struct ast_channel *chan,struct vm_state *vms)
+static int vm_intro(struct ast_channel *chan,struct ast_vm_user *vmu,struct vm_state *vms)
 {
 	/* Play voicemail intro - syntax is different for different languages */
 	if (!strcasecmp(chan->language, "de")) {	/* GERMAN syntax */
@@ -4516,7 +4559,7 @@
 	} else if (!strcasecmp(chan->language, "no")) {	/* NORWEGIAN syntax */
 		return vm_intro_no(chan, vms);
 	} else {					/* Default to ENGLISH */
-		return vm_intro_en(chan, vms);
+		return vm_intro_en(chan, vmu, vms);
 	}
 }
 
@@ -5178,7 +5221,7 @@
 		}
 	}
 
-	cmd = vm_intro(chan, &vms);
+	cmd = vm_intro(chan, vmu, &vms);
 
 	vms.repeats = 0;
 	vms.starting = 1;
@@ -5823,6 +5866,7 @@
 	char *send_voicemail;
 	char *astcallop;
 	char *astreview;
+	char *asttempgreetset;
 	char *astskipcmd;
 	char *asthearenv;
 	char *astsaydurationinfo;
@@ -6020,6 +6064,16 @@
 		}
 		ast_set2_flag((&globalflags), ast_true(astreview), VM_REVIEW);	
 
+		/*Temperary greeting reminder */
+		if (!(asttempgreetset = ast_variable_retrieve(cfg, "general", "tempgreetset"))){
+			ast_log(LOG_DEBUG,"VM Temperary Greeting Reminder Option disabled globally\n");
+			asttempgreetset = "no";
+		}
+		else{
+			ast_log(LOG_DEBUG,"VM Temperary Greeting Reminder Option enabled globally\n");
+		}
+		ast_set2_flag((&globalflags), ast_true(asttempgreetset), VM_TEMPGREETSET);	
+
 		if (!(astcallop = ast_variable_retrieve(cfg, "general", "operator"))){
 			ast_log(LOG_DEBUG,"VM Operator break disabled globally\n");
 			astcallop = "no";
